==> Tagz-1.0.0.zip: Tagz/lang/fr.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Mots Clés',
 'L_TITLE'=>'Editer les mots clés du site',
 'L_DESCRIPTION'=>'Gérer les tags du site. Supprimer ou renommer l’ensembles des mots clés.',
#admin
 'L_CANCEL'=>'Tout annuler',
 'L_DEVIENT'=>'devient',
 'L_POUR'=>'pour',
 'L_SEARCH'=>'Rechercher dans les articles avec ce mot clè',
 'L_RESTORE'=>'Rétablir',
 'L_DEL'=>'Effacer',
 'L_RESTORE_ALL'=>'Rétablir tous les champs laissés vides',
 'L_DEL_ALL'=>'Effacer tous les champs',
 'L_ART_NUM'=>'Pour le(s) article(s) avec le(s) numéro(s)',
 'L_HELP_TAG_FIELD'=>'Si le champ est vidé, cela supprime le mot clè après avoir enregistré.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'Rafraichir',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Fichier tags.xml rafraichis par les mots clés des articles',
 'L_TAG_PLACEHOLDER'=>'Supprimé si laisser vide',
 'L_DEDUPLICATED'=>'Dédoublonné',
 'L_IN_REALITY'=>'En réalité',
 'L_IS_UNIK'=>'Uniques (est solo)',
 'L_DOUBLES'=>'Doubles',
 'L_TRIPLES'=>'Triples',
 'L_QUADRUPLES'=>'Quadruples',
 'L_QUINTUPLES'=>'Quintuples',
 'L_SEXTUPLES'=>'Sextuples',
 'L_SEPTUPLES'=>'Septuples',
#config
 'L_ACCES'=>'Type(s) de compte(s)* autorisé(s) a accéder au plugin',
 'L_HELP_ACCES'=>'Quels sont les profils* autorisés a utiliser le plugin. Liste séparés par des virgules (Par defaut : PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Utilisateur(s) interdit d’accés au plugin (Menu caché)',
 'L_HELP_DENY'=>'Quels sont les identifiants des utilisateur a qui il est interdit d’utiliser le plugin. Liste séparés par des virgules (Par exemple : 001,002,007).'
);
?>

==> Tagz-1.0.6.zip: Tagz/lang/fr.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Mots Clés',
 'L_TITLE'=>'Editer les mots clés du site',
 'L_DESCRIPTION'=>'Gérer les tags du site. Supprimer ou renommer l’ensembles des mots clés.',
#admin
 'L_FILTER_TAGS'=>'Filtrer les mots clés',
 'L_FILTER_TAGS_PH'=>'Filtre des mots',
 'L_CANCEL'=>'Tout annuler',
 'L_DEVIENT'=>'devient',
 'L_POUR'=>'pour',
 'L_SEARCH'=>'Rechercher dans les articles avec ce mot clè',
 'L_RESTORE'=>'Rétablir',
 'L_DEL'=>'Effacer',
 'L_RESTORE_ALL'=>'Rétablir tous les champs laissés vides',
 'L_DEL_ALL'=>'Effacer tous les champs',
 'L_ART_NUM'=>'Pour le(s) article(s) avec le(s) numéro(s)',
 'L_HELP_TAG_FIELD'=>'Si le champ est vidé, cela supprime le mot clè après avoir enregistré.',
 'L_HELP_TAG_CTRLZ'=>'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'Rafraichir',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Fichier tags.xml rafraichis par les mots clés des articles',
 'L_TAG_PLACEHOLDER'=>'Supprimé si laisser vide',
 'L_DEDUPLICATED'=>'Dédoublonné',
 'L_IN_REALITY'=>'En réalité',
 'L_IS_UNIK'=>'Uniques (est solo)',
 'L_DOUBLES'=>'Doubles',
 'L_TRIPLES'=>'Triples',
 'L_QUADRUPLES'=>'Quadruples',
 'L_QUINTUPLES'=>'Quintuples',
 'L_SEXTUPLES'=>'Sextuples',
 'L_SEPTUPLES'=>'Septuples',
 'L_OCTUPLES'=>'Octuples',
 'L_NONUPLES'=>'Nonuples',
 'L_DECUPLES'=>'Décuples',
#config
 'L_ACCES'=>'Type(s) de compte(s)* autorisé(s) a accéder au plugin',
 'L_HELP_ACCES'=>'Quels sont les profils* autorisés a utiliser le plugin. Liste séparés par des virgules (Par defaut : PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Utilisateur(s) interdit d’accés au plugin (Menu caché)',
 'L_HELP_DENY'=>'Quels sont les identifiants des utilisateur a qui il est interdit d’utiliser le plugin. Liste séparés par des virgules (Par exemple : 001,002,007).'
);
?>
